##  Recommended Workflow for SAP LeanIX and Collibra Integration
  1. Sync conceptual business assets to SAP LeanIX.
  2. Create the relations to applications in SAP LeanIX using interface fact sheets.
  3. Enrich the data object with data classification, application usage, and data privacy categorization.
  4. Sync applications, interfaces, business capabilities and respective relations to Collibra.


![Recommended Workflow for SAP LeanIX and Collibra Integration](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27487de97a4410149abd904f65f8ac34_LowRes.png)
Recommended Workflow for SAP LeanIX and Collibra Integration
Key assumptions made here:
  * Conceptual business assets are managed in Collibra
  * Applications, interfaces, business capabilities, and all inherent relations are managed in SAP LeanIX
